@@ -5,7 +5,7 @@
 #' @param RH object of class RobinHood
 #' @param order_url (string) url of order returned from place_order
 #' @param limit_output (logical) return limited info on the order (default TRUE)
-#' @import curl magrittr
+#' @import httr magrittr
 #' @export
 #' @examples
 #' \dontrun{
@@ -26,18 +26,20 @@
 #'}
 get_order_status <- function(RH, order_url, limit_output = TRUE) {
 
-  if (class(RH) != "RobinHood") stop("RH must be class RobinHood, see RobinHood()")
+    # Check if RH is valid
+    check_rh(RH)
 
-  # Get Order Status
-  order_status <- api_orders(RH, action = "status", order_url)
+    # Get Order Status
+    order_status <- api_orders(RH, action = "status", order_url)
 
-  if (limit_output == TRUE) {
-    order_status <- list(updated_at = order_status$updated_at,
-                        time_in_force = order_status$time_in_force,
-                        state = order_status$state,
-                        type = order_status$type,
-                        executions = order_status$executions)
-                      }
+    # Give addition order details if requested
+    if (limit_output == TRUE) {
+      order_status <- list(updated_at = order_status$updated_at,
+                          time_in_force = order_status$time_in_force,
+                          state = order_status$state,
+                          type = order_status$type,
+                          executions = order_status$executions)
+                        }
 
-  return(order_status)
+     return(order_status)
 }
