@@ -9,7 +9,7 @@
 #' @param stop_price (number) if trigger = stop, enter stop price, otherwise leave blank
 #' @param quantity (int) number of shares you wish to transact
 #' @param side (string) "buy" or "sell"
-#' @import curl magrittr
+#' @import httr magrittr
 #' @export
 #' @examples
 #' \dontrun{
@@ -19,7 +19,7 @@
 #' # Place an order, should generate an email confirmation
 #'x <- place_order(RH = RH,
 #'                  symbol = "GE",          # Ticker symbol you want to trade
-#'                  type = "market",        # Type of market order
+#'                  type = "market",        # Type of market order (market, limit)
 #'                  time_in_force = "gfd",  # Time period the order is good for (gfd: good for day)
 #'                  trigger = "immediate",  # Trigger or delay order
 #'                  price = 8.96,           # The highest price you are willing to pay
@@ -28,28 +28,29 @@
 #'}
 place_order <- function(RH, symbol, type, time_in_force, trigger, price, stop_price = NA, quantity, side) {
 
-  # Set up error checks
-  if (class(RH) != "RobinHood") stop("RH must be class RobinHood, see RobinHood()")
-  if (!type %in% c("market", "type")) stop("type must be 'market' or 'type'")
-  if (!time_in_force %in% c("gfd", "gtc", "ioc", "opg")) stop(" time_in_fore must be one of 'gfd', 'gtc', 'ioc', 'opg'")
-  if (!trigger %in% c("immediate", "stop")) stop("trigger must be 'immediate' or 'stope'")
-  if (trigger == "stop" & is.na(stop_price) == TRUE) stop("stop price cant be null if trigger == 'stop'")
-  if (quantity < 1) stop("quantity must be > 0")
-  if (!side %in% c("buy", "sell")) stop("side must be 'buy' or 'sell'")
+    # Check if RH is valid
+    check_rh(RH)
 
-  # Convert NAs to NULL and numeric to character
-  if (is.na(stop_price) == TRUE) stop_price <- ""
-  quantity <- as.character(quantity)
-  price <- as.character(price)
+    # Set up error checks
+    if (!type %in% c("market", "limit")) stop("type must be 'market' or 'limit'")
+    if (!time_in_force %in% c("gfd", "gtc", "ioc", "opg")) stop(" time_in_fore must be one of 'gfd', 'gtc', 'ioc', 'opg'")
+    if (!trigger %in% c("immediate", "stop")) stop("trigger must be 'immediate' or 'stop'")
+    if (trigger == "stop" & is.na(stop_price) == TRUE) stop("stop price cant be null if trigger == 'stop'")
+    if (quantity < 1) stop("quantity must be > 0")
+    if (!side %in% c("buy", "sell")) stop("side must be 'buy' or 'sell'")
 
-  ##############################################################################
-  # Given a symbol, return the instrument_id
-  instrument_url <- paste(api_endpoints(endpoint = "quotes"), symbol, sep = "")
-  instrument <- api_quote(RH, instrument_url)
-  instrument_id <- instrument$instrument
+    # Convert NAs to NULL and numeric to character
+    if (is.na(stop_price) == TRUE) stop_price <- ""
+    quantity <- as.character(quantity)
+    price <- as.character(price)
+
+    # Given a symbol, return the instrument_id
+    instrument_url <- paste(api_endpoints(endpoint = "quotes"), symbol, sep = "")
+    instrument <- api_quote(RH, instrument_url)
+    instrument_id <- instrument$instrument
 
 
-  # Place an order
+    # Place an order
     orders <- api_orders(RH = RH,
                          action = "order",
                          instrument_id = instrument_id,
@@ -62,5 +63,5 @@ place_order <- function(RH, symbol, type, time_in_force, trigger, price, stop_pr
                          quantity = quantity,
                          side = side)
 
-  return(orders)
+    return(orders)
 }
